import 'package:cs_resources/generated/assets.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/my_appbar.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:widgets/widget_export.dart';

import '../../../components/garage_card.dart';
import '../../../components/newfeed_card_header.dart';
import '../../../router/page/community_page_router.dart';
import 'for_rent_vm.dart';

@RoutePage()
class ForrentPage extends HookConsumerWidget {
  const ForrentPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context}) {
    if (context != null) {
      context.router.push(const ForrentPageRoute());
    } else {
      appRouter.push(const ForrentPageRoute());
    }
  }

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final vm = ref.read(forrentVmProvider.notifier);
    return Scaffold(
      // appBar: MyAppBar.appBar(
      //   context,
      //   "Forrent",
      //   backgroundColor: context.appColors.whiteBG,
      // ),
        backgroundColor: ColorUtils.string2Color("#F2F3F6"),
        body: Column(
          children: [
            Expanded(
              child: EasyRefresh(
                // 上拉加载
                onLoad: () async{
                  Log.d("----onLoad");
                  vm.onLoadData();
                },
                // 下拉刷新
                onRefresh: () async{
                  Log.d("----onRefresh");
                  vm.refreshListData();
                },
                child: Padding(
                  padding: const EdgeInsets.all(15.0),
                  child: _buildForrentFeedList(context, ref, vm),
                ),
              ),
            )
          ],
        )
    );
  }

  Widget _buildForrentItem(BuildContext context, WidgetRef ref, item, vm){
    return Container(
      width: double.infinity,
      child: Container(
        decoration: BoxDecoration(
          color: context.appColors.whiteBG,
          borderRadius: BorderRadius.circular(8),
          boxShadow: [
            BoxShadow(
              color: ColorUtils.string2Color('#E5E5E5'),
              offset: const Offset(0, 2),
              blurRadius: 8,
            ),
          ],
        ),
        child: Column(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            mainAxisSize: MainAxisSize.max,
            children: [
              // 卡片头部(头像 标题 时间)
              Expanded(
                child: GarageCard(
                    key: UniqueKey(),
                    itemObj: item,
                    onClickColleciotn: (dynamic collectionValue){
                      Log.d("点击了收藏按钮  --${item['id']}-$collectionValue");
                      return true;
                    }
                ),
              ),
            ]
        ),
      ),
    );
  }

  Widget _buildForrentFeedList(BuildContext context, WidgetRef ref, vm){
    final itemList = vm.state.list?? [];
    if(itemList.isEmpty){
      return const Center(child: Text('No Data'));
    }else {
      List itemsList = vm.state.list.toList();
      return GridView.builder(
        gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
          crossAxisCount: 2, // 每行显示两个项目
          mainAxisSpacing: 15,
          crossAxisSpacing: 15,
          childAspectRatio: 0.78, // 宽高比
        ),
        key: UniqueKey(),
        itemCount: itemsList.length,
        itemBuilder: (context, index) {
          return _buildForrentItem(context, ref, itemsList[index], vm);
        },
      );
    }
  }
}