import 'package:cpt_community/modules/garage/garagesale_detail/garagesale_detail_vm.dart';
import 'package:cpt_community/router/page/community_page_router.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/my_text_view.dart';

@RoutePage()
class GaragesaleDetailPage extends HookConsumerWidget {
  final int? id;
  final String? type;  // forsale  forrent

  const GaragesaleDetailPage({Key? key, required this.id, required this.type}) : super(key: key);
  // 启动当前页面
  static void startInstance({BuildContext? context, int? id, String? type = 'forsale'}) {
    if (context != null) {
      context.router.push(GaragesaleDetailPageRoute(id: id, type: type));
    } else {
      appRouter.push(GaragesaleDetailPageRoute(id: id, type: type));
    }
  }


  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final state = ref.watch(garagesaleDetailVmProvider);
    final vm = ref.read(garagesaleDetailVmProvider.notifier);
    final String pageTitle = (type == 'forsale') ? 'For Sale' :'For Rent';

    useEffect((){
      // 组件挂载时执行 - 执行接口请求
      Future.microtask(() => vm.initPageData());
      return () {
        // 组件卸载时执行
      };
    },[]);

    return Scaffold(
      appBar: MyAppBar.appBar(
        context,
        pageTitle,
        backgroundColor: context.appColors.whiteBG,
      ),
      backgroundColor: context.appColors.backgroundDefault,
      body: Column(
        children: [
          Expanded(
            child: Stack(
              children:[
                LoadStateLayout(
                  state: state.loadingState,
                  errorMessage: state.errorMessage,
                  errorRetry: () {
                    vm.retryRequest();
                  },
                  successWidget: SingleChildScrollView(
                    scrollDirection: Axis.vertical,
                    physics: const BouncingScrollPhysics(),
                    clipBehavior: Clip.none,
                    child: _buildContentBox(context, ref),
                  ),
                ),
                Visibility(
                  visible: state.loadingState == LoadState.State_Success,
                  child: _buildWhatsApp(context, ref),
                ),
              ]
            ),
          ),
          // 底部联系信息
          Visibility(
            visible: state.loadingState == LoadState.State_Success,
            child: _buildBottomConcatInfo(context, ref),
          )
        ],
      ),
    );
  }

  Widget _buildWhatsApp(BuildContext context, WidgetRef ref) {
    final vm = ref.read(garagesaleDetailVmProvider.notifier);
    return Positioned(
      right: 15.5,
      bottom: 42,
      child: InkWell(
        onTap: () {
          // 跳转 WhatsApp
          vm.gotoWhatsApp();
        },
        child: const MyAssetImage(Assets.communityWhatsAPP, width: 57,height: 57,),
      ),
    );
  }

  Widget _buildContentBox(BuildContext context, WidgetRef ref) {
    final vm = ref.read(garagesaleDetailVmProvider.notifier);
    final state = ref.watch(garagesaleDetailVmProvider);
    String title = state.datas!['title'] ?? '';
    String price = state.datas!['price'] ?? '';
    String description = state.datas!['description'] ?? '';
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        // 图片
        SizedBox(
          width: double.infinity,
          height: 173.5,
          child: MyLoadImage(
            state.datas!['goods_img'],
          ),
        ),
        Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            // 标题
            Padding(
              padding: const EdgeInsets.only(left: 16, right: 16, top: 16,),
              child: title.isNotEmpty? MyTextView( title, fontSize: 18, isFontMedium: true, textColor: context.appColors.textBlack,):const SizedBox.shrink(),
            ),
            // 价格
            Padding(
              padding: const EdgeInsets.only(left: 16, right: 16, top: 10),
              child: price.isNotEmpty? MyTextView( price, fontSize: 24, isFontMedium: true, textColor: context.appColors.textBlack,):const SizedBox.shrink(),
            ),
           //  内容
            Padding(
              padding: const EdgeInsets.only(left: 16, right: 16, top: 16),
              child: description.isNotEmpty? MyTextView( description, fontSize: 17, isFontRegular: true, textColor: context.appColors.textBlack,):const SizedBox.shrink(),
            ),
          ],
        ),

      ]
    );
  }

  Widget _buildBottomConcatInfo(BuildContext context, WidgetRef ref) {
    final state = ref.watch(garagesaleDetailVmProvider);
    String publisher = state.datas!['publisher'] ?? '';
    String publisherAvatar = state.datas!['publisher_avatar'] ?? '';
    String publisherTime = state.datas!['publisher_time'] ?? '';
    int collectionNum = state.datas!['collection_num'] ?? 0;
    return Container(
      height: 50,
      color: ColorUtils.string2Color('#4161D0'),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Expanded(
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                SizedBox.fromSize(size: const Size(15, 0)),
                MyLoadImage(
                  publisherAvatar,
                  width: 29,
                  height: 29,
                  isCircle: true,
                ),
                SizedBox.fromSize(size: const Size(10, 0)),
                Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    MyTextView(publisher, fontSize:12, textColor: context.appColors.textWhite, isFontMedium: true,),
                    MyTextView(publisherTime, fontSize:10, textColor: context.appColors.textWhite, isFontRegular: true, marginTop: 4,)
                  ],
                ),
              ],
            ),
          ),
          Expanded(
            child: Row(
              mainAxisAlignment: MainAxisAlignment.end,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                const MyAssetImage(Assets.communityCollection, width: 18,height: 18,),
                MyTextView(
                  "$collectionNum",
                  fontSize: 18,
                  textColor: Colors.white,
                  isFontRegular: true,
                  marginLeft: 5,
                  marginRight: 15,
                ),
                const SizedBox(width: 4,),
                const MyAssetImage(Assets.communityPhone, width: 21.5,height: 18,),
                const SizedBox(width: 15,),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
